@@ -21,7 +21,7 @@ our $DEBUG;
 our $VERIFY_PREFIX = "use Types::Common -types, -sigs;";
 
 BEGIN {
-  our $VERSION = qv(8.4.3);
+  our $VERSION = qv(8.5.0);
   XSLoader::load("sealed", $VERSION);
 }
 
@@ -192,7 +192,11 @@ sub MODIFY_CODE_ATTRIBUTES {
 
 sub import {
   $DEBUG                         = $_[1];
-  our $VERIFY_PREFIX = $_[2] if $DEBUG eq "verify" and defined $_[2];
+  our $VERIFY_PREFIX = $_[2] if $DEBUG eq "verify" and @_ == 3;
+  local $@;
+  my $pkg = caller;
+  eval {"package $pkg; use class; use types"}; # enable perl type system
+  die $@ if $@;
   filter_add(bless []);
 }
 
@@ -221,8 +225,9 @@ sub filter {
      my $suffix = "";
      my $verify = "";
      my (@types, @vars, @defaults);
-
-     s{(\S+)?\s*(\$\w+)(\s*\S*=\s*[^,]+)?(\s*,\s*)?}{ # comma-separated sig args
+     my $entry;
+     s{(\S+)\s*(\$\w+)(\s*\S*=\s*[^,]+)?(\s*,\s*)?}{ # comma-separated sig args
+       $entry++;
        local $@;
        no strict 'refs';
 
@@ -256,7 +261,7 @@ sub filter {
        "$2$3$4" # drop the class/type info
     }gmse;
 
-    if ($DEBUG eq "verify") {
+    if ($entry and $DEBUG eq "verify") {
       # implement signature type checks for named subs via Types::Common::signature
 
       $verify .= "$VERIFY_PREFIX; no strict qw/vars subs/; state \$check = signature multiple => [ { named_to_list => 1, named => [";
@@ -300,11 +305,14 @@ sealed - Subroutine attribute for compile-time method lookups on its typed lexic
     use sealed 'dump';    # warns with the $op->dump during the tree walk
     use sealed 'verify';  # verifies all CV tweaks, optional VERIFY_PREFIX arg
     use sealed 'disabled';# disables all CV tweaks
+    use sealed 'types';   # enables builtin Perl::Types type system optimizations
     use sealed;           # disables all warnings
 
     VERIFY_PREFIX arg defaults to "use Types::Common -types, -sigs;", which
     must export an equivalent API to Types::Common::signature() as "signature()".
 
+    NOTE: as of 8.5.0, import activates the Perl Type System automatically.
+
 =head1 BUGS
 
 You may need to simplify your named method call argument stack,
